@@ -40,7 +40,7 @@ class BaseApiWrapper:
             self.__headers.update(extra_headers)
     entity_type = None
 
-    __headers = {
+    __base_headers = {
         'Content-Type': 'application/json',
         'Accept': 'application/json',
     }
@@ -79,10 +79,10 @@ class BaseApiWrapper:
 
     @property
     def headers(self):
-        headers = self.__headers
+        headers = self.__base_headers.copy()
         headers.update({'Authorization': f'Bearer {self.token}'})
         if self.impersonate:
-            headers.update({'CallerObjectId': self.impersonate})
+            headers.update({'MSCRMCallerID': self.impersonate})
         return headers
 
     @property
